SQLAlchemy 0.5 Documentation - module sqlalchemy.databases.informix

# SQLAlchemy 0.5 Documentation

Multiple Pages | One Page
Version: 0.5.0rc3 Last Updated: 11/07/08 13:55:35

### module sqlalchemy.databases.informix

### class InfoBinary(Binary)

def get_col_spec(self)
back to section top

### class InfoBoolean(Boolean)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class InfoChar(CHAR)

def get_col_spec(self)
back to section top

### class InfoCompiler(DefaultCompiler)

Info compiler modifies the lexical structure of Select statements to work under non-ANSI configured Oracle databases, if the use_ansi flag is False.

def __init__(self, *args, **kwargs)

Construct a new `InfoCompiler`.

def default_from(self)
def get_select_precolumns(self, select)
def limit_clause(self, select)
def visit_clauselist(self, list, **kwargs)
def visit_function(self, func)
def visit_select(self, select)
back to section top

### class InfoDate(Date)

def get_col_spec(self)
back to section top

### class InfoDateTime(DateTime)

def bind_processor(self, dialect)
def get_col_spec(self)
back to section top

### class InfoDialect(DefaultDialect)

def __init__(self, use_ansi=True, **kwargs)

Construct a new `InfoDialect`.

def create_connect_args(self, url)
def create_execution_context(self, *args, **kwargs)
def dbapi(cls)
def do_begin(self, connect)
def has_table(self, connection, table_name, schema=None)
def is_disconnect(self, e)
def reflecttable(self, connection, table, include_columns)
def table_names(self, connection, schema)
def type_descriptor(self, typeobj)
back to section top

### class InfoExecutionContext(DefaultExecutionContext)

def create_cursor(self)
def post_exec(self)
back to section top

### class InfoIdentifierPreparer(IdentifierPreparer)

def __init__(self, dialect)

Construct a new `InfoIdentifierPreparer`.

back to section top

### class InfoInteger(Integer)

def get_col_spec(self)
back to section top

### class InfoNumeric(Numeric)

def get_col_spec(self)
back to section top

### class InfoSchemaDropper(SchemaDropper)

def drop_foreignkey(self, constraint)
back to section top

### class InfoSchemaGenerator(SchemaGenerator)

def define_foreign_key(self, constraint)
def get_column_specification(self, column, first_pk=False)
def post_create_table(self, table)
def visit_foreign_key_constraint(self, constraint)
def visit_index(self, index)
def visit_primary_key_constraint(self, constraint)
def visit_unique_constraint(self, constraint)
back to section top

### class InfoSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class InfoString(String)

def bind_processor(self, dialect)
def get_col_spec(self)
back to section top

### class InfoText(String)

def get_col_spec(self)
back to section top

### class InfoTime(Time)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SingletonThreadPool(Pool)

A Pool that maintains one connection per thread.

Maintains one connection per each thread, never moving a connection to a thread other than the one which it was created in.

This is used for SQLite, which both does not handle multithreading by default, and also requires a singleton connection if a :memory: database is being used.

Options are the same as those of Pool, as well as:

pool_size: 5
  The number of threads in which to maintain connections at once.

def __init__(self, creator, pool_size=5, **params)

Construct a new `SingletonThreadPool`.

def cleanup(self)
def dispose(self)

Dispose of this pool.

def dispose_local(self)
def do_get(self)
def do_return_conn(self, conn)
def recreate(self)
def status(self)
back to section top

### class informix_cursor(object)

def __init__(self, con)

Construct a new `informix_cursor`.

def execute(self, sql, params)
def offset(self, n)
def __getattr__(self, name)
back to section top